@@ -36,7 +36,7 @@ class SliceValues(object):
             catId = sp["CATEGORY"]
             if catId not in schemaDataDictById:
                 logger.debug("slicefilter %s category missing %s keys %r", sliceFilter, catId, list(schemaDataDictById.keys()))
-                logger.info("slicefilter %s category missing %s", sliceFilter, catId)
+                # logger.info("slicefilter %s category missing %s", sliceFilter, catId)
         vD = {}
         for sp in spiL:
             catId = sp["CATEGORY"]
